Commit Diff


commit - b67fc13f024a3abdc6cb7510eb2f7f528b4f753c
commit + b1bc859966228e901e8d75cc437e30b380c53a26
blob - a466f61684c3bbf7e1b4ae76bd8d30e819eab059
blob + 72f880f521d09321e44166ba36e385bc1ee678d0
--- richard/packages/mullvad.scm
+++ richard/packages/mullvad.scm
@@ -16,7 +16,8 @@
   #:use-module (guix build-system trivial)
   #:use-module (guix gexp)
   #:use-module ((guix licenses) #:prefix license:)
-  #:use-module (gnu packages base)         ; glibc, tar, binutils
+  #:use-module (gnu packages base)         ; glibc, tar
+  #:use-module (gnu packages binutils)    ; binutils (ar)
   #:use-module (gnu packages compression) ; xz
   #:use-module (gnu packages elf)          ; patchelf
   #:export (mullvad-vpn))
blob - 910721b1cee6bdb5547794a993832141c966a782
blob + a6eea048e312a0fd4d3f3c3118e4678eb242a5ab
--- system/home.scm
+++ system/home.scm
@@ -68,7 +68,7 @@ max-cache-ttl     7200
 
 # pinentry-curses: funciona en cualquier terminal sin depender de display
 # Necesario porque SSH auth expira si se espera a que aparezca una ventana Qt
-pinentry-program pinentry-curses
+pinentry-program /home/richard/.guix-home/profile/bin/pinentry-curses
 "))
 
 ;; ══════════════════════════════════════════════════════════════════
@@ -82,7 +82,7 @@ pinentry-program pinentry-curses
     (map specification->package
          '(;; GPG / YubiKey
            "gnupg"
-           "pinentry-qt"          ; diálogo PIN para KDE Plasma
+           "pinentry"             ; incluye pinentry-curses para prompts de PIN
            "openssh"              ; ssh, ssh-add, ssh-keygen
 
            ;; Herramientas de desarrollo
@@ -104,5 +104,5 @@ pinentry-program pinentry-curses
                  (bashrc (list %yubikey-bashrc))))
 
       ;; ── gpg-agent.conf ──────────────────────────────────────
-      (service home-files-service-type
-               `((".gnupg/gpg-agent.conf" ,%gpg-agent-conf))))))
+      (simple-service 'gpg-agent-conf home-files-service-type
+                      `((".gnupg/gpg-agent.conf" ,%gpg-agent-conf))))))
--- system/config.scm
+++ system/config.scm
@@ -15,16 +15,20 @@
   (gnu services desktop)
   (gnu services xorg)
   (gnu services networking)
+  (gnu services linux)             ; kernel-module-loader-service-type
   (gnu services security-token)   ; pcscd para YubiKey
   (gnu services nftables)         ; firewall
+  ;; Transformaciones de paquetes
+  (guix transformations)          ; options->transformation
   ;; Paquetes auxiliares para xorg
   (gnu packages xorg)
   ;; nonguix — kernel no-libre + NVIDIA
   (nongnu packages linux)
   (nongnu packages nvidia)
   (nongnu system linux-initrd)
-  ;; Canal personal — Mullvad VPN
-  (richard services mullvad))
+  ;; Canal personal — Mullvad VPN + Zen Browser
+  (richard services mullvad)
+  (richard packages zen-browser))
 
 ;; ══════════════════════════════════════════════════════════════════
 ;; NVIDIA — graft y configuración PRIME
@@ -228,13 +232,8 @@
         ;; ── Kleopatra (gestión GPG) ───────────────────────────────
         (specification->package "kleopatra")
 
-        ;; ── Flatpak — para Zen Browser ────────────────────────────
-        ;; Zen Browser no está en los canales de Guix todavía.
-        ;; Después de instalar el sistema:
-        ;;   flatpak remote-add --if-not-exists flathub \
-        ;;     https://dl.flathub.org/repo/flathub.flatpakrepo
-        ;;   flatpak install flathub app.zen_browser.zen
-        (specification->package "flatpak"))
+        ;; ── Zen Browser — canal richard ───────────────────────────
+        zen-browser)
 
       %base-packages))
 
blob - 10bb8f1cacb55ffd4659618e9c9bd59b3e3ddd2a
blob + 3ff4544f05e54946c2f502a10af6be93646eb976